# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.test_helpers.terminal._reader_present_payment_method_params import (
    ReaderPresentPaymentMethodParams as ReaderPresentPaymentMethodParams,
    ReaderPresentPaymentMethodParamsCard as ReaderPresentPaymentMethodParamsCard,
    ReaderPresentPaymentMethodParamsCardPresent as ReaderPresentPaymentMethodParamsCardPresent,
    ReaderPresentPaymentMethodParamsInteracPresent as ReaderPresentPaymentMethodParamsInteracPresent,
)
from stripe.params.test_helpers.terminal._reader_succeed_input_collection_params import (
    ReaderSucceedInputCollectionParams as ReaderSucceedInputCollectionParams,
)
from stripe.params.test_helpers.terminal._reader_timeout_input_collection_params import (
    ReaderTimeoutInputCollectionParams as ReaderTimeoutInputCollectionParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2.core import accounts as accounts, vault as vault
from stripe.params.v2.core._account_close_params import (
    AccountCloseParams as AccountCloseParams,
)
from stripe.params.v2.core._account_create_params import (
    AccountCreateParams as AccountCreateParams,
    AccountCreateParamsConfiguration as AccountCreateParamsConfiguration,
    AccountCreateParamsConfigurationCardCreator as AccountCreateParamsConfigurationCardCreator,
    AccountCreateParamsConfigurationCardCreatorCapabilities as AccountCreateParamsConfigurationCardCreatorCapabilities,
    AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercial as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercial,
    AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic,
    AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard,
    AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard,
    AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank,
    AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard,
    AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard,
    AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripe as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripe,
    AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard,
    AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard,
    AccountCreateParamsConfigurationCustomer as AccountCreateParamsConfigurationCustomer,
    AccountCreateParamsConfigurationCustomerAutomaticIndirectTax as AccountCreateParamsConfigurationCustomerAutomaticIndirectTax,
    AccountCreateParamsConfigurationCustomerBilling as AccountCreateParamsConfigurationCustomerBilling,
    AccountCreateParamsConfigurationCustomerBillingInvoice as AccountCreateParamsConfigurationCustomerBillingInvoice,
    AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField as AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField,
    AccountCreateParamsConfigurationCustomerBillingInvoiceRendering as AccountCreateParamsConfigurationCustomerBillingInvoiceRendering,
    AccountCreateParamsConfigurationCustomerCapabilities as AccountCreateParamsConfigurationCustomerCapabilities,
    AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax as AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax,
    AccountCreateParamsConfigurationCustomerShipping as AccountCreateParamsConfigurationCustomerShipping,
    AccountCreateParamsConfigurationCustomerShippingAddress as AccountCreateParamsConfigurationCustomerShippingAddress,
    AccountCreateParamsConfigurationMerchant as AccountCreateParamsConfigurationMerchant,
    AccountCreateParamsConfigurationMerchantBacsDebitPayments as AccountCreateParamsConfigurationMerchantBacsDebitPayments,
    AccountCreateParamsConfigurationMerchantBranding as AccountCreateParamsConfigurationMerchantBranding,
    AccountCreateParamsConfigurationMerchantCapabilities as AccountCreateParamsConfigurationMerchantCapabilities,
    AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments as AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments as AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments as AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments as AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments as AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments as AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments,
    AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments as AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments,
    AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments as AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments,
    AccountCreateParamsConfigurationMerchantCardPayments as AccountCreateParamsConfigurationMerchantCardPayments,
    AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn as AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn,
    AccountCreateParamsConfigurationMerchantStatementDescriptor as AccountCreateParamsConfigurationMerchantStatementDescriptor,
    AccountCreateParamsConfigurationMerchantSupport as AccountCreateParamsConfigurationMerchantSupport,
    AccountCreateParamsConfigurationMerchantSupportAddress as AccountCreateParamsConfigurationMerchantSupportAddress,
    AccountCreateParamsConfigurationRecipient as AccountCreateParamsConfigurationRecipient,
    AccountCreateParamsConfigurationRecipientCapabilities as AccountCreateParamsConfigurationRecipientCapabilities,
    AccountCreateParamsConfigurationRecipientCapabilitiesBankAccounts as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccounts,
    AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocal as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocal,
    AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWire as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWire,
    AccountCreateParamsConfigurationRecipientCapabilitiesCards as AccountCreateParamsConfigurationRecipientCapabilitiesCards,
    AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWallets as AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWallets,
    AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance as AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance,
    AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers as AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers,
    AccountCreateParamsConfigurationStorer as AccountCreateParamsConfigurationStorer,
    AccountCreateParamsConfigurationStorerCapabilities as AccountCreateParamsConfigurationStorerCapabilities,
    AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddresses as AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddresses,
    AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddressesBankAccounts as AccountCreateParamsConfigurationStorerCapabilitiesFinancialAddressesBankAccounts,
    AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrencies as AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrencies,
    AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrenciesGbp as AccountCreateParamsConfigurationStorerCapabilitiesHoldsCurrenciesGbp,
    AccountCreateParamsConfigurationStorerCapabilitiesInboundTransfers as AccountCreateParamsConfigurationStorerCapabilitiesInboundTransfers,
    AccountCreateParamsConfigurationStorerCapabilitiesInboundTransfersBankAccounts as AccountCreateParamsConfigurationStorerCapabilitiesInboundTransfersBankAccounts,
    AccountCreateParamsConfigurationStorerCapabilitiesOutboundPayments as AccountCreateParamsConfigurationStorerCapabilitiesOutboundPayments,
    AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsBankAccounts as AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsBankAccounts,
    AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsCards as AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsCards,
    AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsFinancialAccounts as AccountCreateParamsConfigurationStorerCapabilitiesOutboundPaymentsFinancialAccounts,
    AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfers as AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfers,
    AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersBankAccounts as AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersBankAccounts,
    AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersFinancialAccounts as AccountCreateParamsConfigurationStorerCapabilitiesOutboundTransfersFinancialAccounts,
    AccountCreateParamsDefaults as AccountCreateParamsDefaults,
    AccountCreateParamsDefaultsProfile as AccountCreateParamsDefaultsProfile,
    AccountCreateParamsDefaultsResponsibilities as AccountCreateParamsDefaultsResponsibilities,
    AccountCreateParamsIdentity as AccountCreateParamsIdentity,
    AccountCreateParamsIdentityAttestations as AccountCreateParamsIdentityAttestations,
    AccountCreateParamsIdentityAttestationsDirectorshipDeclaration as AccountCreateParamsIdentityAttestationsDirectorshipDeclaration,
    AccountCreateParamsIdentityAttestationsOwnershipDeclaration as AccountCreateParamsIdentityAttestationsOwnershipDeclaration,
    AccountCreateParamsIdentityAttestationsPersonsProvided as AccountCreateParamsIdentityAttestationsPersonsProvided,
    AccountCreateParamsIdentityAttestationsTermsOfService as AccountCreateParamsIdentityAttestationsTermsOfService,
    AccountCreateParamsIdentityAttestationsTermsOfServiceAccount as AccountCreateParamsIdentityAttestationsTermsOfServiceAccount,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreator as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreator,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms,
    AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures,
    AccountCreateParamsIdentityAttestationsTermsOfServiceStorer as AccountCreateParamsIdentityAttestationsTermsOfServiceStorer,
    AccountCreateParamsIdentityBusinessDetails as AccountCreateParamsIdentityBusinessDetails,
    AccountCreateParamsIdentityBusinessDetailsAddress as AccountCreateParamsIdentityBusinessDetailsAddress,
    AccountCreateParamsIdentityBusinessDetailsAnnualRevenue as AccountCreateParamsIdentityBusinessDetailsAnnualRevenue,
    AccountCreateParamsIdentityBusinessDetailsDocuments as AccountCreateParamsIdentityBusinessDetailsDocuments,
    AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
    AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
    AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
    AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
    AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
    AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
    AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
    AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
    AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
    AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
    AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
    AccountCreateParamsIdentityBusinessDetailsIdNumber as AccountCreateParamsIdentityBusinessDetailsIdNumber,
    AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
    AccountCreateParamsIdentityBusinessDetailsScriptAddresses as AccountCreateParamsIdentityBusinessDetailsScriptAddresses,
    AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana as AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana,
    AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji,
    AccountCreateParamsIdentityBusinessDetailsScriptNames as AccountCreateParamsIdentityBusinessDetailsScriptNames,
    AccountCreateParamsIdentityBusinessDetailsScriptNamesKana as AccountCreateParamsIdentityBusinessDetailsScriptNamesKana,
    AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji as AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji,
    AccountCreateParamsIdentityIndividual as AccountCreateParamsIdentityIndividual,
    AccountCreateParamsIdentityIndividualAdditionalAddress as AccountCreateParamsIdentityIndividualAdditionalAddress,
    AccountCreateParamsIdentityIndividualAdditionalName as AccountCreateParamsIdentityIndividualAdditionalName,
    AccountCreateParamsIdentityIndividualAddress as AccountCreateParamsIdentityIndividualAddress,
    AccountCreateParamsIdentityIndividualDateOfBirth as AccountCreateParamsIdentityIndividualDateOfBirth,
    AccountCreateParamsIdentityIndividualDocuments as AccountCreateParamsIdentityIndividualDocuments,
    AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization,
    AccountCreateParamsIdentityIndividualDocumentsPassport as AccountCreateParamsIdentityIndividualDocumentsPassport,
    AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification as AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification,
    AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
    AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification as AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification,
    AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
    AccountCreateParamsIdentityIndividualDocumentsVisa as AccountCreateParamsIdentityIndividualDocumentsVisa,
    AccountCreateParamsIdentityIndividualIdNumber as AccountCreateParamsIdentityIndividualIdNumber,
    AccountCreateParamsIdentityIndividualRelationship as AccountCreateParamsIdentityIndividualRelationship,
    AccountCreateParamsIdentityIndividualScriptAddresses as AccountCreateParamsIdentityIndividualScriptAddresses,
    AccountCreateParamsIdentityIndividualScriptAddressesKana as AccountCreateParamsIdentityIndividualScriptAddressesKana,
    AccountCreateParamsIdentityIndividualScriptAddressesKanji as AccountCreateParamsIdentityIndividualScriptAddressesKanji,
    AccountCreateParamsIdentityIndividualScriptNames as AccountCreateParamsIdentityIndividualScriptNames,
    AccountCreateParamsIdentityIndividualScriptNamesKana as AccountCreateParamsIdentityIndividualScriptNamesKana,
    AccountCreateParamsIdentityIndividualScriptNamesKanji as AccountCreateParamsIdentityIndividualScriptNamesKanji,
)
from stripe.params.v2.core._account_link_create_params import (
    AccountLinkCreateParams as AccountLinkCreateParams,
    AccountLinkCreateParamsUseCase as AccountLinkCreateParamsUseCase,
    AccountLinkCreateParamsUseCaseAccountOnboarding as AccountLinkCreateParamsUseCaseAccountOnboarding,
    AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions as AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions,
    AccountLinkCreateParamsUseCaseAccountUpdate as AccountLinkCreateParamsUseCaseAccountUpdate,
    AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions as AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions,
)
from stripe.params.v2.core._account_list_params import (
    AccountListParams as AccountListParams,
)
from stripe.params.v2.core._account_retrieve_params import (
    AccountRetrieveParams as AccountRetrieveParams,
)
from stripe.params.v2.core._account_update_params import (
    AccountUpdateParams as AccountUpdateParams,
    AccountUpdateParamsConfiguration as AccountUpdateParamsConfiguration,
    AccountUpdateParamsConfigurationCardCreator as AccountUpdateParamsConfigurationCardCreator,
    AccountUpdateParamsConfigurationCardCreatorCapabilities as AccountUpdateParamsConfigurationCardCreatorCapabilities,
    AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercial as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercial,
    AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic,
    AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard,
    AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard,
    AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank,
    AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard,
    AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard,
    AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripe as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripe,
    AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard,
    AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard,
    AccountUpdateParamsConfigurationCustomer as AccountUpdateParamsConfigurationCustomer,
    AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax as AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax,
    AccountUpdateParamsConfigurationCustomerBilling as AccountUpdateParamsConfigurationCustomerBilling,
    AccountUpdateParamsConfigurationCustomerBillingInvoice as AccountUpdateParamsConfigurationCustomerBillingInvoice,
    AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField as AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField,
    AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering as AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering,
    AccountUpdateParamsConfigurationCustomerCapabilities as AccountUpdateParamsConfigurationCustomerCapabilities,
    AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax as AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax,
    AccountUpdateParamsConfigurationCustomerShipping as AccountUpdateParamsConfigurationCustomerShipping,
    AccountUpdateParamsConfigurationCustomerShippingAddress as AccountUpdateParamsConfigurationCustomerShippingAddress,
    AccountUpdateParamsConfigurationMerchant as AccountUpdateParamsConfigurationMerchant,
    AccountUpdateParamsConfigurationMerchantBacsDebitPayments as AccountUpdateParamsConfigurationMerchantBacsDebitPayments,
    AccountUpdateParamsConfigurationMerchantBranding as AccountUpdateParamsConfigurationMerchantBranding,
    AccountUpdateParamsConfigurationMerchantCapabilities as AccountUpdateParamsConfigurationMerchantCapabilities,
    AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments as AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments,
    AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments,
    AccountUpdateParamsConfigurationMerchantCardPayments as AccountUpdateParamsConfigurationMerchantCardPayments,
    AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn as AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn,
    AccountUpdateParamsConfigurationMerchantStatementDescriptor as AccountUpdateParamsConfigurationMerchantStatementDescriptor,
    AccountUpdateParamsConfigurationMerchantSupport as AccountUpdateParamsConfigurationMerchantSupport,
    AccountUpdateParamsConfigurationMerchantSupportAddress as AccountUpdateParamsConfigurationMerchantSupportAddress,
    AccountUpdateParamsConfigurationRecipient as AccountUpdateParamsConfigurationRecipient,
    AccountUpdateParamsConfigurationRecipientCapabilities as AccountUpdateParamsConfigurationRecipientCapabilities,
    AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccounts as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccounts,
    AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocal as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocal,
    AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWire as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWire,
    AccountUpdateParamsConfigurationRecipientCapabilitiesCards as AccountUpdateParamsConfigurationRecipientCapabilitiesCards,
    AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWallets as AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWallets,
    AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance as AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance,
    AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers as AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers,
    AccountUpdateParamsConfigurationStorer as AccountUpdateParamsConfigurationStorer,
    AccountUpdateParamsConfigurationStorerCapabilities as AccountUpdateParamsConfigurationStorerCapabilities,
    AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddresses as AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddresses,
    AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddressesBankAccounts as AccountUpdateParamsConfigurationStorerCapabilitiesFinancialAddressesBankAccounts,
    AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrencies as AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrencies,
    AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrenciesGbp as AccountUpdateParamsConfigurationStorerCapabilitiesHoldsCurrenciesGbp,
    AccountUpdateParamsConfigurationStorerCapabilitiesInboundTransfers as AccountUpdateParamsConfigurationStorerCapabilitiesInboundTransfers,
    AccountUpdateParamsConfigurationStorerCapabilitiesInboundTransfersBankAccounts as AccountUpdateParamsConfigurationStorerCapabilitiesInboundTransfersBankAccounts,
    AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPayments as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPayments,
    AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsBankAccounts as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsBankAccounts,
    AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsCards as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsCards,
    AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsFinancialAccounts as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundPaymentsFinancialAccounts,
    AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfers as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfers,
    AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersBankAccounts as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersBankAccounts,
    AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersFinancialAccounts as AccountUpdateParamsConfigurationStorerCapabilitiesOutboundTransfersFinancialAccounts,
    AccountUpdateParamsDefaults as AccountUpdateParamsDefaults,
    AccountUpdateParamsDefaultsProfile as AccountUpdateParamsDefaultsProfile,
    AccountUpdateParamsDefaultsResponsibilities as AccountUpdateParamsDefaultsResponsibilities,
    AccountUpdateParamsIdentity as AccountUpdateParamsIdentity,
    AccountUpdateParamsIdentityAttestations as AccountUpdateParamsIdentityAttestations,
    AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration as AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration,
    AccountUpdateParamsIdentityAttestationsOwnershipDeclaration as AccountUpdateParamsIdentityAttestationsOwnershipDeclaration,
    AccountUpdateParamsIdentityAttestationsPersonsProvided as AccountUpdateParamsIdentityAttestationsPersonsProvided,
    AccountUpdateParamsIdentityAttestationsTermsOfService as AccountUpdateParamsIdentityAttestationsTermsOfService,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount as AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreator as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreator,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures,
    AccountUpdateParamsIdentityAttestationsTermsOfServiceStorer as AccountUpdateParamsIdentityAttestationsTermsOfServiceStorer,
    AccountUpdateParamsIdentityBusinessDetails as AccountUpdateParamsIdentityBusinessDetails,
    AccountUpdateParamsIdentityBusinessDetailsAddress as AccountUpdateParamsIdentityBusinessDetailsAddress,
    AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue as AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue,
    AccountUpdateParamsIdentityBusinessDetailsDocuments as AccountUpdateParamsIdentityBusinessDetailsDocuments,
    AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
    AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
    AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
    AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
    AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
    AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
    AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
    AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
    AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
    AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
    AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
    AccountUpdateParamsIdentityBusinessDetailsIdNumber as AccountUpdateParamsIdentityBusinessDetailsIdNumber,
    AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
    AccountUpdateParamsIdentityBusinessDetailsScriptAddresses as AccountUpdateParamsIdentityBusinessDetailsScriptAddresses,
    AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana as AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana,
    AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji,
    AccountUpdateParamsIdentityBusinessDetailsScriptNames as AccountUpdateParamsIdentityBusinessDetailsScriptNames,
    AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana as AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana,
    AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji as AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji,
    AccountUpdateParamsIdentityIndividual as AccountUpdateParamsIdentityIndividual,
    AccountUpdateParamsIdentityIndividualAdditionalAddress as AccountUpdateParamsIdentityIndividualAdditionalAddress,
    AccountUpdateParamsIdentityIndividualAdditionalName as AccountUpdateParamsIdentityIndividualAdditionalName,
    AccountUpdateParamsIdentityIndividualAddress as AccountUpdateParamsIdentityIndividualAddress,
    AccountUpdateParamsIdentityIndividualDateOfBirth as AccountUpdateParamsIdentityIndividualDateOfBirth,
    AccountUpdateParamsIdentityIndividualDocuments as AccountUpdateParamsIdentityIndividualDocuments,
    AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization,
    AccountUpdateParamsIdentityIndividualDocumentsPassport as AccountUpdateParamsIdentityIndividualDocumentsPassport,
    AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification as AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification,
    AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
    AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification as AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification,
    AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
    AccountUpdateParamsIdentityIndividualDocumentsVisa as AccountUpdateParamsIdentityIndividualDocumentsVisa,
    AccountUpdateParamsIdentityIndividualIdNumber as AccountUpdateParamsIdentityIndividualIdNumber,
    AccountUpdateParamsIdentityIndividualRelationship as AccountUpdateParamsIdentityIndividualRelationship,
    AccountUpdateParamsIdentityIndividualScriptAddresses as AccountUpdateParamsIdentityIndividualScriptAddresses,
    AccountUpdateParamsIdentityIndividualScriptAddressesKana as AccountUpdateParamsIdentityIndividualScriptAddressesKana,
    AccountUpdateParamsIdentityIndividualScriptAddressesKanji as AccountUpdateParamsIdentityIndividualScriptAddressesKanji,
    AccountUpdateParamsIdentityIndividualScriptNames as AccountUpdateParamsIdentityIndividualScriptNames,
    AccountUpdateParamsIdentityIndividualScriptNamesKana as AccountUpdateParamsIdentityIndividualScriptNamesKana,
    AccountUpdateParamsIdentityIndividualScriptNamesKanji as AccountUpdateParamsIdentityIndividualScriptNamesKanji,
)
from stripe.params.v2.core._claimable_sandbox_create_params import (
    ClaimableSandboxCreateParams as ClaimableSandboxCreateParams,
    ClaimableSandboxCreateParamsPrefill as ClaimableSandboxCreateParamsPrefill,
)
from stripe.params.v2.core._claimable_sandbox_retrieve_params import (
    ClaimableSandboxRetrieveParams as ClaimableSandboxRetrieveParams,
)
from stripe.params.v2.core._event_destination_create_params import (
    EventDestinationCreateParams as EventDestinationCreateParams,
    EventDestinationCreateParamsAmazonEventbridge as EventDestinationCreateParamsAmazonEventbridge,
    EventDestinationCreateParamsWebhookEndpoint as EventDestinationCreateParamsWebhookEndpoint,
)
from stripe.params.v2.core._event_destination_delete_params import (
    EventDestinationDeleteParams as EventDestinationDeleteParams,
)
from stripe.params.v2.core._event_destination_disable_params import (
    EventDestinationDisableParams as EventDestinationDisableParams,
)
from stripe.params.v2.core._event_destination_enable_params import (
    EventDestinationEnableParams as EventDestinationEnableParams,
)
from stripe.params.v2.core._event_destination_list_params import (
    EventDestinationListParams as EventDestinationListParams,
)
from stripe.params.v2.core._event_destination_ping_params import (
    EventDestinationPingParams as EventDestinationPingParams,
)
from stripe.params.v2.core._event_destination_retrieve_params import (
    EventDestinationRetrieveParams as EventDestinationRetrieveParams,
)
from stripe.params.v2.core._event_destination_update_params import (
    EventDestinationUpdateParams as EventDestinationUpdateParams,
    EventDestinationUpdateParamsWebhookEndpoint as EventDestinationUpdateParamsWebhookEndpoint,
)
from stripe.params.v2.core._event_list_params import (
    EventListParams as EventListParams,
)
from stripe.params.v2.core._event_retrieve_params import (
    EventRetrieveParams as EventRetrieveParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.v2.tax._automatic_rule import AutomaticRule as AutomaticRule
from stripe.v2.tax._automatic_rule_service import (
    AutomaticRuleService as AutomaticRuleService,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2.payments._off_session_payment_cancel_params import (
    OffSessionPaymentCancelParams as OffSessionPaymentCancelParams,
)
from stripe.params.v2.payments._off_session_payment_capture_params import (
    OffSessionPaymentCaptureParams as OffSessionPaymentCaptureParams,
    OffSessionPaymentCaptureParamsTransferData as OffSessionPaymentCaptureParamsTransferData,
)
from stripe.params.v2.payments._off_session_payment_create_params import (
    OffSessionPaymentCreateParams as OffSessionPaymentCreateParams,
    OffSessionPaymentCreateParamsAmountDetails as OffSessionPaymentCreateParamsAmountDetails,
    OffSessionPaymentCreateParamsAmountDetailsLineItem as OffSessionPaymentCreateParamsAmountDetailsLineItem,
    OffSessionPaymentCreateParamsAmountDetailsLineItemTax as OffSessionPaymentCreateParamsAmountDetailsLineItemTax,
    OffSessionPaymentCreateParamsAmountDetailsShipping as OffSessionPaymentCreateParamsAmountDetailsShipping,
    OffSessionPaymentCreateParamsAmountDetailsTax as OffSessionPaymentCreateParamsAmountDetailsTax,
    OffSessionPaymentCreateParamsCapture as OffSessionPaymentCreateParamsCapture,
    OffSessionPaymentCreateParamsPaymentMethodOptions as OffSessionPaymentCreateParamsPaymentMethodOptions,
    OffSessionPaymentCreateParamsPaymentMethodOptionsCard as OffSessionPaymentCreateParamsPaymentMethodOptionsCard,
    OffSessionPaymentCreateParamsPaymentsOrchestration as OffSessionPaymentCreateParamsPaymentsOrchestration,
    OffSessionPaymentCreateParamsRetryDetails as OffSessionPaymentCreateParamsRetryDetails,
    OffSessionPaymentCreateParamsTransferData as OffSessionPaymentCreateParamsTransferData,
)
from stripe.params.v2.payments._off_session_payment_list_params import (
    OffSessionPaymentListParams as OffSessionPaymentListParams,
)
from stripe.params.v2.payments._off_session_payment_retrieve_params import (
    OffSessionPaymentRetrieveParams as OffSessionPaymentRetrieveParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.privacy._redaction_job_cancel_params import (
    RedactionJobCancelParams as RedactionJobCancelParams,
)
from stripe.params.privacy._redaction_job_create_params import (
    RedactionJobCreateParams as RedactionJobCreateParams,
    RedactionJobCreateParamsObjects as RedactionJobCreateParamsObjects,
)
from stripe.params.privacy._redaction_job_list_params import (
    RedactionJobListParams as RedactionJobListParams,
)
from stripe.params.privacy._redaction_job_list_validation_errors_params import (
    RedactionJobListValidationErrorsParams as RedactionJobListValidationErrorsParams,
)
from stripe.params.privacy._redaction_job_modify_params import (
    RedactionJobModifyParams as RedactionJobModifyParams,
)
from stripe.params.privacy._redaction_job_retrieve_params import (
    RedactionJobRetrieveParams as RedactionJobRetrieveParams,
)
from stripe.params.privacy._redaction_job_run_params import (
    RedactionJobRunParams as RedactionJobRunParams,
)
from stripe.params.privacy._redaction_job_update_params import (
    RedactionJobUpdateParams as RedactionJobUpdateParams,
)
from stripe.params.privacy._redaction_job_validate_params import (
    RedactionJobValidateParams as RedactionJobValidateParams,
)
from stripe.params.privacy._redaction_job_validation_error_list_params import (
    RedactionJobValidationErrorListParams as RedactionJobValidationErrorListParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from stripe.v2._list_object import ListObject
from stripe.v2.core._account import Account
from stripe.v2.core.accounts._person_service import PersonService
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.v2.core._account_close_params import AccountCloseParams
    from stripe.params.v2.core._account_create_params import (
        AccountCreateParams,
    )
    from stripe.params.v2.core._account_list_params import AccountListParams
    from stripe.params.v2.core._account_retrieve_params import (
        AccountRetrieveParams,
    )
    from stripe.params.v2.core._account_update_params import (
        AccountUpdateParams,
    )


class AccountService(StripeService):
    def __init__(self, requestor):
        super().__init__(requestor)
        self.persons = PersonService(self._requestor)

    def list(
        self,
        params: Optional["AccountListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[Account]:
        """
        Returns a list of Accounts.
        """
        return cast(
            ListObject[Account],
            self._request(
                "get",
                "/v2/core/accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["AccountListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[Account]:
        """
        Returns a list of Accounts.
        """
        return cast(
            ListObject[Account],
            await self._request_async(
                "get",
                "/v2/core/accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: Optional["AccountCreateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Account:
        """
        An Account is a representation of a company, individual or other entity that a user interacts with. Accounts contain identifying information about the entity, and configurations that store the features an account has access to. An account can be configured as any or all of the following configurations: Customer, Merchant and/or Recipient.
        """
        return cast(
            Account,
            self._request(
                "post",
                "/v2/core/accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: Optional["AccountCreateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Account:
        """
        An Account is a representation of a company, individual or other entity that a user interacts with. Accounts contain identifying information about the entity, and configurations that store the features an account has access to. An account can be configured as any or all of the following configurations: Customer, Merchant and/or Recipient.
        """
        return cast(
            Account,
            await self._request_async(
                "post",
                "/v2/core/accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        id: str,
        params: Optional["AccountRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Account:
        """
        Retrieves the details of an Account.
        """
        return cast(
            Account,
            self._request(
                "get",
                "/v2/core/accounts/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        id: str,
        params: Optional["AccountRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Account:
        """
        Retrieves the details of an Account.
        """
        return cast(
            Account,
            await self._request_async(
                "get",
                "/v2/core/accounts/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def update(
        self,
        id: str,
        params: Optional["AccountUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Account:
        """
        Updates the details of an Account.
        """
        return cast(
            Account,
            self._request(
                "post",
                "/v2/core/accounts/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        id: str,
        params: Optional["AccountUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Account:
        """
        Updates the details of an Account.
        """
        return cast(
            Account,
            await self._request_async(
                "post",
                "/v2/core/accounts/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def close(
        self,
        id: str,
        params: Optional["AccountCloseParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Account:
        """
        Removes access to the Account and its associated resources.
        """
        return cast(
            Account,
            self._request(
                "post",
                "/v2/core/accounts/{id}/close".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def close_async(
        self,
        id: str,
        params: Optional["AccountCloseParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Account:
        """
        Removes access to the Account and its associated resources.
        """
        return cast(
            Account,
            await self._request_async(
                "post",
                "/v2/core/accounts/{id}/close".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2 import (
    billing as billing,
    core as core,
    money_management as money_management,
    payments as payments,
    tax as tax,
    test_helpers as test_helpers,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.billing.analytics._meter_usage import MeterUsage as MeterUsage
from stripe.billing.analytics._meter_usage_row import (
    MeterUsageRow as MeterUsageRow,
)
from stripe.billing.analytics._meter_usage_service import (
    MeterUsageService as MeterUsageService,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.delegated_checkout._requested_session import (
    RequestedSession as RequestedSession,
)
from stripe.delegated_checkout._requested_session_service import (
    RequestedSessionService as RequestedSessionService,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._api_mode import ApiMode
from stripe._api_requestor import _APIRequestor
from stripe._stripe_object import StripeObject
from stripe._stripe_response import StripeResponse
from stripe.v2.core._event import Event, EventNotification
from typing import Any, Dict, Optional, cast
from typing_extensions import Literal, override


class V2CoreHealthEventGenerationFailureResolvedEventNotification(
    EventNotification,
):
    LOOKUP_TYPE = "v2.core.health.event_generation_failure.resolved"
    type: Literal["v2.core.health.event_generation_failure.resolved"]

    @override
    def fetch_event(self) -> "V2CoreHealthEventGenerationFailureResolvedEvent":
        return cast(
            "V2CoreHealthEventGenerationFailureResolvedEvent",
            super().fetch_event(),
        )

    @override
    async def fetch_event_async(
        self,
    ) -> "V2CoreHealthEventGenerationFailureResolvedEvent":
        return cast(
            "V2CoreHealthEventGenerationFailureResolvedEvent",
            await super().fetch_event_async(),
        )


class V2CoreHealthEventGenerationFailureResolvedEvent(Event):
    LOOKUP_TYPE = "v2.core.health.event_generation_failure.resolved"
    type: Literal["v2.core.health.event_generation_failure.resolved"]

    class V2CoreHealthEventGenerationFailureResolvedEventData(StripeObject):
        class Impact(StripeObject):
            account: Optional[str]
            """
            The account id the event should have been generated for. Only present when the account is a connected account.
            """
            event_type: str
            """
            The type of event that Stripe failed to generate.
            """
            livemode: bool
            """
            Indicates if the event was for livemode or not.
            """
            missing_delivery_attempts: int
            """
            The number of webhooks that Stripe failed to create and deliver.
            """
            related_object_id: str
            """
            The related object id.
            """

        alert_id: str
        """
        The alert ID.
        """
        grouping_key: str
        """
        The grouping key for the alert.
        """
        impact: Impact
        """
        The user impact.
        """
        resolved_at: str
        """
        The time when the user experience has returned to expected levels.
        """
        summary: str
        """
        A short description of the alert.
        """
        _inner_class_types = {"impact": Impact}

    data: V2CoreHealthEventGenerationFailureResolvedEventData
    """
    Data for the v2.core.health.event_generation_failure.resolved event
    """

    @classmethod
    def _construct_from(
        cls,
        *,
        values: Dict[str, Any],
        last_response: Optional[StripeResponse] = None,
        requestor: "_APIRequestor",
        api_mode: ApiMode,
    ) -> "V2CoreHealthEventGenerationFailureResolvedEvent":
        evt = super()._construct_from(
            values=values,
            last_response=last_response,
            requestor=requestor,
            api_mode=api_mode,
        )
        if hasattr(evt, "data"):
            evt.data = V2CoreHealthEventGenerationFailureResolvedEvent.V2CoreHealthEventGenerationFailureResolvedEventData._construct_from(
                values=evt.data,
                last_response=last_response,
                requestor=requestor,
                api_mode=api_mode,
            )
        return evt



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2.core.vault._gb_bank_account_acknowledge_confirmation_of_payee_params import (
    GbBankAccountAcknowledgeConfirmationOfPayeeParams as GbBankAccountAcknowledgeConfirmationOfPayeeParams,
)
from stripe.params.v2.core.vault._gb_bank_account_archive_params import (
    GbBankAccountArchiveParams as GbBankAccountArchiveParams,
)
from stripe.params.v2.core.vault._gb_bank_account_create_params import (
    GbBankAccountCreateParams as GbBankAccountCreateParams,
    GbBankAccountCreateParamsConfirmationOfPayee as GbBankAccountCreateParamsConfirmationOfPayee,
)
from stripe.params.v2.core.vault._gb_bank_account_initiate_confirmation_of_payee_params import (
    GbBankAccountInitiateConfirmationOfPayeeParams as GbBankAccountInitiateConfirmationOfPayeeParams,
)
from stripe.params.v2.core.vault._gb_bank_account_retrieve_params import (
    GbBankAccountRetrieveParams as GbBankAccountRetrieveParams,
)
from stripe.params.v2.core.vault._us_bank_account_archive_params import (
    UsBankAccountArchiveParams as UsBankAccountArchiveParams,
)
from stripe.params.v2.core.vault._us_bank_account_create_params import (
    UsBankAccountCreateParams as UsBankAccountCreateParams,
)
from stripe.params.v2.core.vault._us_bank_account_retrieve_params import (
    UsBankAccountRetrieveParams as UsBankAccountRetrieveParams,
)
from stripe.params.v2.core.vault._us_bank_account_update_params import (
    UsBankAccountUpdateParams as UsBankAccountUpdateParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.test_helpers.issuing._authorization_capture_params import (
    AuthorizationCaptureParams as AuthorizationCaptureParams,
    AuthorizationCaptureParamsPurchaseDetails as AuthorizationCaptureParamsPurchaseDetails,
    AuthorizationCaptureParamsPurchaseDetailsFleet as AuthorizationCaptureParamsPurchaseDetailsFleet,
    AuthorizationCaptureParamsPurchaseDetailsFleetCardholderPromptData as AuthorizationCaptureParamsPurchaseDetailsFleetCardholderPromptData,
    AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdown as AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdown,
    AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownFuel as AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownFuel,
    AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownNonFuel as AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownNonFuel,
    AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownTax as AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownTax,
    AuthorizationCaptureParamsPurchaseDetailsFlight as AuthorizationCaptureParamsPurchaseDetailsFlight,
    AuthorizationCaptureParamsPurchaseDetailsFlightSegment as AuthorizationCaptureParamsPurchaseDetailsFlightSegment,
    AuthorizationCaptureParamsPurchaseDetailsFuel as AuthorizationCaptureParamsPurchaseDetailsFuel,
    AuthorizationCaptureParamsPurchaseDetailsLodging as AuthorizationCaptureParamsPurchaseDetailsLodging,
    AuthorizationCaptureParamsPurchaseDetailsReceipt as AuthorizationCaptureParamsPurchaseDetailsReceipt,
)
from stripe.params.test_helpers.issuing._authorization_create_params import (
    AuthorizationCreateParams as AuthorizationCreateParams,
    AuthorizationCreateParamsAmountDetails as AuthorizationCreateParamsAmountDetails,
    AuthorizationCreateParamsFleet as AuthorizationCreateParamsFleet,
    AuthorizationCreateParamsFleetCardholderPromptData as AuthorizationCreateParamsFleetCardholderPromptData,
    AuthorizationCreateParamsFleetReportedBreakdown as AuthorizationCreateParamsFleetReportedBreakdown,
    AuthorizationCreateParamsFleetReportedBreakdownFuel as AuthorizationCreateParamsFleetReportedBreakdownFuel,
    AuthorizationCreateParamsFleetReportedBreakdownNonFuel as AuthorizationCreateParamsFleetReportedBreakdownNonFuel,
    AuthorizationCreateParamsFleetReportedBreakdownTax as AuthorizationCreateParamsFleetReportedBreakdownTax,
    AuthorizationCreateParamsFuel as AuthorizationCreateParamsFuel,
    AuthorizationCreateParamsMerchantData as AuthorizationCreateParamsMerchantData,
    AuthorizationCreateParamsNetworkData as AuthorizationCreateParamsNetworkData,
    AuthorizationCreateParamsRiskAssessment as AuthorizationCreateParamsRiskAssessment,
    AuthorizationCreateParamsRiskAssessmentCardTestingRisk as AuthorizationCreateParamsRiskAssessmentCardTestingRisk,
    AuthorizationCreateParamsRiskAssessmentMerchantDisputeRisk as AuthorizationCreateParamsRiskAssessmentMerchantDisputeRisk,
    AuthorizationCreateParamsVerificationData as AuthorizationCreateParamsVerificationData,
    AuthorizationCreateParamsVerificationDataAuthenticationExemption as AuthorizationCreateParamsVerificationDataAuthenticationExemption,
    AuthorizationCreateParamsVerificationDataThreeDSecure as AuthorizationCreateParamsVerificationDataThreeDSecure,
)
from stripe.params.test_helpers.issuing._authorization_expire_params import (
    AuthorizationExpireParams as AuthorizationExpireParams,
)
from stripe.params.test_helpers.issuing._authorization_finalize_amount_params import (
    AuthorizationFinalizeAmountParams as AuthorizationFinalizeAmountParams,
    AuthorizationFinalizeAmountParamsFleet as AuthorizationFinalizeAmountParamsFleet,
    AuthorizationFinalizeAmountParamsFleetCardholderPromptData as AuthorizationFinalizeAmountParamsFleetCardholderPromptData,
    AuthorizationFinalizeAmountParamsFleetReportedBreakdown as AuthorizationFinalizeAmountParamsFleetReportedBreakdown,
    AuthorizationFinalizeAmountParamsFleetReportedBreakdownFuel as AuthorizationFinalizeAmountParamsFleetReportedBreakdownFuel,
    AuthorizationFinalizeAmountParamsFleetReportedBreakdownNonFuel as AuthorizationFinalizeAmountParamsFleetReportedBreakdownNonFuel,
    AuthorizationFinalizeAmountParamsFleetReportedBreakdownTax as AuthorizationFinalizeAmountParamsFleetReportedBreakdownTax,
    AuthorizationFinalizeAmountParamsFuel as AuthorizationFinalizeAmountParamsFuel,
)
from stripe.params.test_helpers.issuing._authorization_increment_params import (
    AuthorizationIncrementParams as AuthorizationIncrementParams,
)
from stripe.params.test_helpers.issuing._authorization_respond_params import (
    AuthorizationRespondParams as AuthorizationRespondParams,
)
from stripe.params.test_helpers.issuing._authorization_reverse_params import (
    AuthorizationReverseParams as AuthorizationReverseParams,
)
from stripe.params.test_helpers.issuing._card_deliver_card_params import (
    CardDeliverCardParams as CardDeliverCardParams,
)
from stripe.params.test_helpers.issuing._card_fail_card_params import (
    CardFailCardParams as CardFailCardParams,
)
from stripe.params.test_helpers.issuing._card_return_card_params import (
    CardReturnCardParams as CardReturnCardParams,
)
from stripe.params.test_helpers.issuing._card_ship_card_params import (
    CardShipCardParams as CardShipCardParams,
)
from stripe.params.test_helpers.issuing._card_submit_card_params import (
    CardSubmitCardParams as CardSubmitCardParams,
)
from stripe.params.test_helpers.issuing._personalization_design_activate_params import (
    PersonalizationDesignActivateParams as PersonalizationDesignActivateParams,
)
from stripe.params.test_helpers.issuing._personalization_design_deactivate_params import (
    PersonalizationDesignDeactivateParams as PersonalizationDesignDeactivateParams,
)
from stripe.params.test_helpers.issuing._personalization_design_reject_params import (
    PersonalizationDesignRejectParams as PersonalizationDesignRejectParams,
    PersonalizationDesignRejectParamsRejectionReasons as PersonalizationDesignRejectParamsRejectionReasons,
)
from stripe.params.test_helpers.issuing._transaction_create_force_capture_params import (
    TransactionCreateForceCaptureParams as TransactionCreateForceCaptureParams,
    TransactionCreateForceCaptureParamsMerchantData as TransactionCreateForceCaptureParamsMerchantData,
    TransactionCreateForceCaptureParamsPurchaseDetails as TransactionCreateForceCaptureParamsPurchaseDetails,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleet as TransactionCreateForceCaptureParamsPurchaseDetailsFleet,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetCardholderPromptData as TransactionCreateForceCaptureParamsPurchaseDetailsFleetCardholderPromptData,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdown as TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdown,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownFuel as TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownFuel,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownNonFuel as TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownNonFuel,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownTax as TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownTax,
    TransactionCreateForceCaptureParamsPurchaseDetailsFlight as TransactionCreateForceCaptureParamsPurchaseDetailsFlight,
    TransactionCreateForceCaptureParamsPurchaseDetailsFlightSegment as TransactionCreateForceCaptureParamsPurchaseDetailsFlightSegment,
    TransactionCreateForceCaptureParamsPurchaseDetailsFuel as TransactionCreateForceCaptureParamsPurchaseDetailsFuel,
    TransactionCreateForceCaptureParamsPurchaseDetailsLodging as TransactionCreateForceCaptureParamsPurchaseDetailsLodging,
    TransactionCreateForceCaptureParamsPurchaseDetailsReceipt as TransactionCreateForceCaptureParamsPurchaseDetailsReceipt,
)
from stripe.params.test_helpers.issuing._transaction_create_unlinked_refund_params import (
    TransactionCreateUnlinkedRefundParams as TransactionCreateUnlinkedRefundParams,
    TransactionCreateUnlinkedRefundParamsMerchantData as TransactionCreateUnlinkedRefundParamsMerchantData,
    TransactionCreateUnlinkedRefundParamsPurchaseDetails as TransactionCreateUnlinkedRefundParamsPurchaseDetails,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleet as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleet,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetCardholderPromptData as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetCardholderPromptData,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdown as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdown,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownFuel as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownFuel,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownNonFuel as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownNonFuel,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownTax as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownTax,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFlight as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFlight,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFlightSegment as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFlightSegment,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFuel as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFuel,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsLodging as TransactionCreateUnlinkedRefundParamsPurchaseDetailsLodging,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsReceipt as TransactionCreateUnlinkedRefundParamsPurchaseDetailsReceipt,
)
from stripe.params.test_helpers.issuing._transaction_refund_params import (
    TransactionRefundParams as TransactionRefundParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.v2.billing.rate_cards._rate_service import (
    RateService as RateService,
)
from stripe.v2.billing.rate_cards._version_service import (
    VersionService as VersionService,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import List
from typing_extensions import Literal, NotRequired, TypedDict


class ChargeCaptureParams(RequestOptions):
    amount: NotRequired[int]
    """
    The amount to capture, which must be less than or equal to the original amount.
    """
    application_fee: NotRequired[int]
    """
    An application fee to add on to this charge.
    """
    application_fee_amount: NotRequired[int]
    """
    An application fee amount to add on to this charge, which must be less than or equal to the original amount.
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    payment_details: NotRequired["ChargeCaptureParamsPaymentDetails"]
    """
    Provides industry-specific information about the charge.
    """
    receipt_email: NotRequired[str]
    """
    The email address to send this charge's receipt to. This will override the previously-specified email address for this charge, if one was set. Receipts will not be sent in test mode.
    """
    statement_descriptor: NotRequired[str]
    """
    For a non-card charge, text that appears on the customer's statement as the statement descriptor. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](https://docs.stripe.com/get-started/account/statement-descriptors).

    For a card charge, this value is ignored unless you don't specify a `statement_descriptor_suffix`, in which case this value is used as the suffix.
    """
    statement_descriptor_suffix: NotRequired[str]
    """
    Provides information about a card charge. Concatenated to the account's [statement descriptor prefix](https://docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer's statement. If the account has no prefix value, the suffix is concatenated to the account's statement descriptor.
    """
    transfer_data: NotRequired["ChargeCaptureParamsTransferData"]
    """
    An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](https://stripe.com/docs/connect/destination-charges) for details.
    """
    transfer_group: NotRequired[str]
    """
    A string that identifies this transaction as part of a group. `transfer_group` may only be provided if it has not been set. See the [Connect documentation](https://stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.
    """


class ChargeCaptureParamsPaymentDetails(TypedDict):
    car_rental: NotRequired["ChargeCaptureParamsPaymentDetailsCarRental"]
    """
    Car rental details for this PaymentIntent.
    """
    customer_reference: NotRequired["Literal['']|str"]
    """
    Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
    """
    event_details: NotRequired["ChargeCaptureParamsPaymentDetailsEventDetails"]
    """
    Event details for this PaymentIntent
    """
    flight: NotRequired["ChargeCaptureParamsPaymentDetailsFlight"]
    """
    Flight reservation details for this PaymentIntent
    """
    lodging: NotRequired["ChargeCaptureParamsPaymentDetailsLodging"]
    """
    Lodging reservation details for this PaymentIntent
    """
    order_reference: NotRequired["Literal['']|str"]
    """
    A unique value assigned by the business to identify the transaction.
    """
    subscription: NotRequired["ChargeCaptureParamsPaymentDetailsSubscription"]
    """
    Subscription details for this PaymentIntent
    """


class ChargeCaptureParamsPaymentDetailsCarRental(TypedDict):
    affiliate: NotRequired[
        "ChargeCaptureParamsPaymentDetailsCarRentalAffiliate"
    ]
    """
    Affiliate details for this purchase.
    """
    booking_number: str
    """
    The booking number associated with the car rental.
    """
    car_class_code: NotRequired[str]
    """
    Class code of the car.
    """
    car_make: NotRequired[str]
    """
    Make of the car.
    """
    car_model: NotRequired[str]
    """
    Model of the car.
    """
    company: NotRequired[str]
    """
    The name of the rental car company.
    """
    customer_service_phone_number: NotRequired[str]
    """
    The customer service phone number of the car rental company.
    """
    days_rented: int
    """
    Number of days the car is being rented.
    """
    delivery: NotRequired["ChargeCaptureParamsPaymentDetailsCarRentalDelivery"]
    """
    Delivery details for this purchase.
    """
    distance: NotRequired["ChargeCaptureParamsPaymentDetailsCarRentalDistance"]
    """
    The details of the distance traveled during the rental period.
    """
    drivers: NotRequired[
        List["ChargeCaptureParamsPaymentDetailsCarRentalDriver"]
    ]
    """
    The details of the passengers in the travel reservation
    """
    extra_charges: NotRequired[
        List[
            Literal[
                "extra_mileage",
                "gas",
                "late_return",
                "one_way_service",
                "parking_violation",
            ]
        ]
    ]
    """
    List of additional charges being billed.
    """
    no_show: NotRequired[bool]
    """
    Indicates if the customer did not keep nor cancel their booking.
    """
    pickup_address: NotRequired[
        "ChargeCaptureParamsPaymentDetailsCarRentalPickupAddress"
    ]
    """
    Car pick-up address.
    """
    pickup_at: int
    """
    Car pick-up time. Measured in seconds since the Unix epoch.
    """
    pickup_location_name: NotRequired[str]
    """
    Name of the pickup location.
    """
    rate_amount: NotRequired[int]
    """
    Rental rate.
    """
    rate_interval: NotRequired[Literal["day", "month", "week"]]
    """
    The frequency at which the rate amount is applied. One of `day`, `week` or `month`
    """
    renter_name: NotRequired[str]
    """
    The name of the person or entity renting the car.
    """
    return_address: NotRequired[
        "ChargeCaptureParamsPaymentDetailsCarRentalReturnAddress"
    ]
    """
    Car return address.
    """
    return_at: int
    """
    Car return time. Measured in seconds since the Unix epoch.
    """
    return_location_name: NotRequired[str]
    """
    Name of the return location.
    """
    tax_exempt: NotRequired[bool]
    """
    Indicates whether the goods or services are tax-exempt or tax is not collected.
    """
    vehicle_identification_number: NotRequired[str]
    """
    The vehicle identification number.
    """


class ChargeCaptureParamsPaymentDetailsCarRentalAffiliate(TypedDict):
    name: str
    """
    The name of the affiliate that originated the purchase.
    """


class ChargeCaptureParamsPaymentDetailsCarRentalDelivery(TypedDict):
    mode: NotRequired[Literal["email", "phone", "pickup", "post"]]
    """
    The delivery method for the payment
    """
    recipient: NotRequired[
        "ChargeCaptureParamsPaymentDetailsCarRentalDeliveryRecipient"
    ]
    """
    Details of the recipient.
    """


class ChargeCaptureParamsPaymentDetailsCarRentalDeliveryRecipient(TypedDict):
    email: NotRequired[str]
    """
    The email of the recipient the ticket is delivered to.
    """
    name: NotRequired[str]
    """
    The name of the recipient the ticket is delivered to.
    """
    phone: NotRequired[str]
    """
    The phone number of the recipient the ticket is delivered to.
    """


class ChargeCaptureParamsPaymentDetailsCarRentalDistance(TypedDict):
    amount: NotRequired[int]
    """
    Distance traveled.
    """
    unit: NotRequired[Literal["kilometers", "miles"]]
    """
    Unit of measurement for the distance traveled. One of `miles` or `kilometers`.
    """


class ChargeCaptureParamsPaymentDetailsCarRentalDriver(TypedDict):
    driver_identification_number: NotRequired[str]
    """
    Driver's identification number.
    """
    driver_tax_number: NotRequired[str]
    """
    Driver's tax number.
    """
    name: str
    """
    Full name of the person or entity on the car reservation.
    """


class ChargeCaptureParamsPaymentDetailsCarRentalPickupAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1, such as the street, PO Box, or company name.
    """
    line2: NotRequired[str]
    """
    Address line 2, such as the apartment, suite, unit, or building.
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """


class ChargeCaptureParamsPaymentDetailsCarRentalReturnAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1, such as the street, PO Box, or company name.
    """
    line2: NotRequired[str]
    """
    Address line 2, such as the apartment, suite, unit, or building.
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """


class ChargeCaptureParamsPaymentDetailsEventDetails(TypedDict):
    access_controlled_venue: NotRequired[bool]
    """
    Indicates if the tickets are digitally checked when entering the venue.
    """
    address: NotRequired[
        "ChargeCaptureParamsPaymentDetailsEventDetailsAddress"
    ]
    """
    The event location's address.
    """
    affiliate: NotRequired[
        "ChargeCaptureParamsPaymentDetailsEventDetailsAffiliate"
    ]
    """
    Affiliate details for this purchase.
    """
    company: NotRequired[str]
    """
    The name of the company
    """
    delivery: NotRequired[
        "ChargeCaptureParamsPaymentDetailsEventDetailsDelivery"
    ]
    """
    Delivery details for this purchase.
    """
    ends_at: NotRequired[int]
    """
    Event end time. Measured in seconds since the Unix epoch.
    """
    genre: NotRequired[str]
    """
    Type of the event entertainment (concert, sports event etc)
    """
    name: str
    """
    The name of the event.
    """
    starts_at: NotRequired[int]
    """
    Event start time. Measured in seconds since the Unix epoch.
    """


class ChargeCaptureParamsPaymentDetailsEventDetailsAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1, such as the street, PO Box, or company name.
    """
    line2: NotRequired[str]
    """
    Address line 2, such as the apartment, suite, unit, or building.
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """


class ChargeCaptureParamsPaymentDetailsEventDetailsAffiliate(TypedDict):
    name: str
    """
    The name of the affiliate that originated the purchase.
    """


class ChargeCaptureParamsPaymentDetailsEventDetailsDelivery(TypedDict):
    mode: NotRequired[Literal["email", "phone", "pickup", "post"]]
    """
    The delivery method for the payment
    """
    recipient: NotRequired[
        "ChargeCaptureParamsPaymentDetailsEventDetailsDeliveryRecipient"
    ]
    """
    Details of the recipient.
    """


class ChargeCaptureParamsPaymentDetailsEventDetailsDeliveryRecipient(
    TypedDict
):
    email: NotRequired[str]
    """
    The email of the recipient the ticket is delivered to.
    """
    name: NotRequired[str]
    """
    The name of the recipient the ticket is delivered to.
    """
    phone: NotRequired[str]
    """
    The phone number of the recipient the ticket is delivered to.
    """


class ChargeCaptureParamsPaymentDetailsFlight(TypedDict):
    affiliate: NotRequired["ChargeCaptureParamsPaymentDetailsFlightAffiliate"]
    """
    Affiliate details for this purchase.
    """
    agency_number: NotRequired[str]
    """
    The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
    """
    carrier: NotRequired[str]
    """
    The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
    """
    delivery: NotRequired["ChargeCaptureParamsPaymentDetailsFlightDelivery"]
    """
    Delivery details for this purchase.
    """
    passenger_name: NotRequired[str]
    """
    The name of the person or entity on the reservation.
    """
    passengers: NotRequired[
        List["ChargeCaptureParamsPaymentDetailsFlightPassenger"]
    ]
    """
    The details of the passengers in the travel reservation.
    """
    segments: List["ChargeCaptureParamsPaymentDetailsFlightSegment"]
    """
    The individual flight segments associated with the trip.
    """
    ticket_number: NotRequired[str]
    """
    The ticket number associated with the travel reservation.
    """


class ChargeCaptureParamsPaymentDetailsFlightAffiliate(TypedDict):
    name: str
    """
    The name of the affiliate that originated the purchase.
    """


class ChargeCaptureParamsPaymentDetailsFlightDelivery(TypedDict):
    mode: NotRequired[Literal["email", "phone", "pickup", "post"]]
    """
    The delivery method for the payment
    """
    recipient: NotRequired[
        "ChargeCaptureParamsPaymentDetailsFlightDeliveryRecipient"
    ]
    """
    Details of the recipient.
    """


class ChargeCaptureParamsPaymentDetailsFlightDeliveryRecipient(TypedDict):
    email: NotRequired[str]
    """
    The email of the recipient the ticket is delivered to.
    """
    name: NotRequired[str]
    """
    The name of the recipient the ticket is delivered to.
    """
    phone: NotRequired[str]
    """
    The phone number of the recipient the ticket is delivered to.
    """


class ChargeCaptureParamsPaymentDetailsFlightPassenger(TypedDict):
    name: str
    """
    Full name of the person or entity on the flight reservation.
    """


class ChargeCaptureParamsPaymentDetailsFlightSegment(TypedDict):
    amount: NotRequired[int]
    """
    The flight segment amount.
    """
    arrival_airport: NotRequired[str]
    """
    The International Air Transport Association (IATA) airport code for the arrival airport.
    """
    arrives_at: NotRequired[int]
    """
    The arrival time for the flight segment. Measured in seconds since the Unix epoch.
    """
    carrier: NotRequired[str]
    """
    The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
    """
    departs_at: int
    """
    The departure time for the flight segment. Measured in seconds since the Unix epoch.
    """
    departure_airport: NotRequired[str]
    """
    The International Air Transport Association (IATA) airport code for the departure airport.
    """
    flight_number: NotRequired[str]
    """
    The flight number associated with the segment
    """
    service_class: NotRequired[
        Literal["business", "economy", "first", "premium_economy"]
    ]
    """
    The fare class for the segment.
    """


class ChargeCaptureParamsPaymentDetailsLodging(TypedDict):
    address: NotRequired["ChargeCaptureParamsPaymentDetailsLodgingAddress"]
    """
    The lodging location's address.
    """
    adults: NotRequired[int]
    """
    The number of adults on the booking
    """
    affiliate: NotRequired["ChargeCaptureParamsPaymentDetailsLodgingAffiliate"]
    """
    Affiliate details for this purchase.
    """
    booking_number: NotRequired[str]
    """
    The booking number associated with the lodging reservation.
    """
    category: NotRequired[Literal["hotel", "vacation_rental"]]
    """
    The lodging category
    """
    checkin_at: int
    """
    Lodging check-in time. Measured in seconds since the Unix epoch.
    """
    checkout_at: int
    """
    Lodging check-out time. Measured in seconds since the Unix epoch.
    """
    customer_service_phone_number: NotRequired[str]
    """
    The customer service phone number of the lodging company.
    """
    daily_room_rate_amount: NotRequired[int]
    """
    The daily lodging room rate.
    """
    delivery: NotRequired["ChargeCaptureParamsPaymentDetailsLodgingDelivery"]
    """
    Delivery details for this purchase.
    """
    extra_charges: NotRequired[
        List[
            Literal[
                "gift_shop",
                "laundry",
                "mini_bar",
                "other",
                "restaurant",
                "telephone",
            ]
        ]
    ]
    """
    List of additional charges being billed.
    """
    fire_safety_act_compliance: NotRequired[bool]
    """
    Indicates whether the lodging location is compliant with the Fire Safety Act.
    """
    name: NotRequired[str]
    """
    The name of the lodging location.
    """
    no_show: NotRequired[bool]
    """
    Indicates if the customer did not keep their booking while failing to cancel the reservation.
    """
    number_of_rooms: NotRequired[int]
    """
    The number of rooms on the booking
    """
    passengers: NotRequired[
        List["ChargeCaptureParamsPaymentDetailsLodgingPassenger"]
    ]
    """
    The details of the passengers in the travel reservation
    """
    property_phone_number: NotRequired[str]
    """
    The phone number of the lodging location.
    """
    room_class: NotRequired[str]
    """
    The room class for this purchase.
    """
    room_nights: NotRequired[int]
    """
    The number of room nights
    """
    total_room_tax_amount: NotRequired[int]
    """
    The total tax amount associating with the room reservation.
    """
    total_tax_amount: NotRequired[int]
    """
    The total tax amount
    """


class ChargeCaptureParamsPaymentDetailsLodgingAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1, such as the street, PO Box, or company name.
    """
    line2: NotRequired[str]
    """
    Address line 2, such as the apartment, suite, unit, or building.
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """


class ChargeCaptureParamsPaymentDetailsLodgingAffiliate(TypedDict):
    name: str
    """
    The name of the affiliate that originated the purchase.
    """


class ChargeCaptureParamsPaymentDetailsLodgingDelivery(TypedDict):
    mode: NotRequired[Literal["email", "phone", "pickup", "post"]]
    """
    The delivery method for the payment
    """
    recipient: NotRequired[
        "ChargeCaptureParamsPaymentDetailsLodgingDeliveryRecipient"
    ]
    """
    Details of the recipient.
    """


class ChargeCaptureParamsPaymentDetailsLodgingDeliveryRecipient(TypedDict):
    email: NotRequired[str]
    """
    The email of the recipient the ticket is delivered to.
    """
    name: NotRequired[str]
    """
    The name of the recipient the ticket is delivered to.
    """
    phone: NotRequired[str]
    """
    The phone number of the recipient the ticket is delivered to.
    """


class ChargeCaptureParamsPaymentDetailsLodgingPassenger(TypedDict):
    name: str
    """
    Full name of the person or entity on the lodging reservation.
    """


class ChargeCaptureParamsPaymentDetailsSubscription(TypedDict):
    affiliate: NotRequired[
        "ChargeCaptureParamsPaymentDetailsSubscriptionAffiliate"
    ]
    """
    Affiliate details for this purchase.
    """
    auto_renewal: NotRequired[bool]
    """
    Info whether the subscription will be auto renewed upon expiry.
    """
    billing_interval: NotRequired[
        "ChargeCaptureParamsPaymentDetailsSubscriptionBillingInterval"
    ]
    """
    Subscription billing details for this purchase.
    """
    ends_at: NotRequired[int]
    """
    Subscription end time. Measured in seconds since the Unix epoch.
    """
    name: str
    """
    Name of the product on subscription. e.g. Apple Music Subscription
    """
    starts_at: NotRequired[int]
    """
    Subscription start time. Measured in seconds since the Unix epoch.
    """


class ChargeCaptureParamsPaymentDetailsSubscriptionAffiliate(TypedDict):
    name: str
    """
    The name of the affiliate that originated the purchase.
    """


class ChargeCaptureParamsPaymentDetailsSubscriptionBillingInterval(TypedDict):
    count: int
    """
    The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
    """
    interval: Literal["day", "month", "week", "year"]
    """
    Specifies a type of interval unit. Either `day`, `week`, `month` or `year`.
    """


class ChargeCaptureParamsTransferData(TypedDict):
    amount: NotRequired[int]
    """
    The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2.billing.rate_cards._rate_create_params import (
    RateCreateParams as RateCreateParams,
    RateCreateParamsCustomPricingUnitAmount as RateCreateParamsCustomPricingUnitAmount,
    RateCreateParamsTier as RateCreateParamsTier,
    RateCreateParamsTransformQuantity as RateCreateParamsTransformQuantity,
)
from stripe.params.v2.billing.rate_cards._rate_delete_params import (
    RateDeleteParams as RateDeleteParams,
)
from stripe.params.v2.billing.rate_cards._rate_list_params import (
    RateListParams as RateListParams,
)
from stripe.params.v2.billing.rate_cards._rate_retrieve_params import (
    RateRetrieveParams as RateRetrieveParams,
)
from stripe.params.v2.billing.rate_cards._version_list_params import (
    VersionListParams as VersionListParams,
)
from stripe.params.v2.billing.rate_cards._version_retrieve_params import (
    VersionRetrieveParams as VersionRetrieveParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing_extensions import NotRequired, TypedDict


class EventListParams(TypedDict):
    limit: NotRequired[int]
    """
    The page size.
    """
    object_id: str
    """
    Primary object ID used to retrieve related events.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2.billing.pricing_plans._component_create_params import (
    ComponentCreateParams as ComponentCreateParams,
    ComponentCreateParamsLicenseFee as ComponentCreateParamsLicenseFee,
    ComponentCreateParamsRateCard as ComponentCreateParamsRateCard,
    ComponentCreateParamsServiceAction as ComponentCreateParamsServiceAction,
)
from stripe.params.v2.billing.pricing_plans._component_delete_params import (
    ComponentDeleteParams as ComponentDeleteParams,
)
from stripe.params.v2.billing.pricing_plans._component_list_params import (
    ComponentListParams as ComponentListParams,
)
from stripe.params.v2.billing.pricing_plans._component_retrieve_params import (
    ComponentRetrieveParams as ComponentRetrieveParams,
)
from stripe.params.v2.billing.pricing_plans._component_update_params import (
    ComponentUpdateParams as ComponentUpdateParams,
)
from stripe.params.v2.billing.pricing_plans._version_list_params import (
    VersionListParams as VersionListParams,
)
from stripe.params.v2.billing.pricing_plans._version_retrieve_params import (
    VersionRetrieveParams as VersionRetrieveParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._list_object import ListObject
from stripe._request_options import RequestOptions
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from stripe.treasury._financial_account import FinancialAccount
from stripe.treasury._financial_account_features_service import (
    FinancialAccountFeaturesService,
)
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.treasury._financial_account_close_params import (
        FinancialAccountCloseParams,
    )
    from stripe.params.treasury._financial_account_create_params import (
        FinancialAccountCreateParams,
    )
    from stripe.params.treasury._financial_account_list_params import (
        FinancialAccountListParams,
    )
    from stripe.params.treasury._financial_account_retrieve_params import (
        FinancialAccountRetrieveParams,
    )
    from stripe.params.treasury._financial_account_update_params import (
        FinancialAccountUpdateParams,
    )


class FinancialAccountService(StripeService):
    def __init__(self, requestor):
        super().__init__(requestor)
        self.features = FinancialAccountFeaturesService(self._requestor)

    def list(
        self,
        params: Optional["FinancialAccountListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[FinancialAccount]:
        """
        Returns a list of FinancialAccounts.
        """
        return cast(
            ListObject[FinancialAccount],
            self._request(
                "get",
                "/v1/treasury/financial_accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["FinancialAccountListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[FinancialAccount]:
        """
        Returns a list of FinancialAccounts.
        """
        return cast(
            ListObject[FinancialAccount],
            await self._request_async(
                "get",
                "/v1/treasury/financial_accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: "FinancialAccountCreateParams",
        options: Optional[RequestOptions] = None,
    ) -> FinancialAccount:
        """
        Creates a new FinancialAccount. Each connected account can have up to three FinancialAccounts by default.
        """
        return cast(
            FinancialAccount,
            self._request(
                "post",
                "/v1/treasury/financial_accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: "FinancialAccountCreateParams",
        options: Optional[RequestOptions] = None,
    ) -> FinancialAccount:
        """
        Creates a new FinancialAccount. Each connected account can have up to three FinancialAccounts by default.
        """
        return cast(
            FinancialAccount,
            await self._request_async(
                "post",
                "/v1/treasury/financial_accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        financial_account: str,
        params: Optional["FinancialAccountRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> FinancialAccount:
        """
        Retrieves the details of a FinancialAccount.
        """
        return cast(
            FinancialAccount,
            self._request(
                "get",
                "/v1/treasury/financial_accounts/{financial_account}".format(
                    financial_account=sanitize_id(financial_account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        financial_account: str,
        params: Optional["FinancialAccountRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> FinancialAccount:
        """
        Retrieves the details of a FinancialAccount.
        """
        return cast(
            FinancialAccount,
            await self._request_async(
                "get",
                "/v1/treasury/financial_accounts/{financial_account}".format(
                    financial_account=sanitize_id(financial_account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def update(
        self,
        financial_account: str,
        params: Optional["FinancialAccountUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> FinancialAccount:
        """
        Updates the details of a FinancialAccount.
        """
        return cast(
            FinancialAccount,
            self._request(
                "post",
                "/v1/treasury/financial_accounts/{financial_account}".format(
                    financial_account=sanitize_id(financial_account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        financial_account: str,
        params: Optional["FinancialAccountUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> FinancialAccount:
        """
        Updates the details of a FinancialAccount.
        """
        return cast(
            FinancialAccount,
            await self._request_async(
                "post",
                "/v1/treasury/financial_accounts/{financial_account}".format(
                    financial_account=sanitize_id(financial_account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def close(
        self,
        financial_account: str,
        params: Optional["FinancialAccountCloseParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> FinancialAccount:
        """
        Closes a FinancialAccount. A FinancialAccount can only be closed if it has a zero balance, has no pending InboundTransfers, and has canceled all attached Issuing cards.
        """
        return cast(
            FinancialAccount,
            self._request(
                "post",
                "/v1/treasury/financial_accounts/{financial_account}/close".format(
                    financial_account=sanitize_id(financial_account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def close_async(
        self,
        financial_account: str,
        params: Optional["FinancialAccountCloseParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> FinancialAccount:
        """
        Closes a FinancialAccount. A FinancialAccount can only be closed if it has a zero balance, has no pending InboundTransfers, and has canceled all attached Issuing cards.
        """
        return cast(
            FinancialAccount,
            await self._request_async(
                "post",
                "/v1/treasury/financial_accounts/{financial_account}/close".format(
                    financial_account=sanitize_id(financial_account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )
